<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Mar 27, 2020
 */

/**
 * Mock class - Dashboard api.
 */

require_once(__DIR__ . '/../../AcronisApi/DashboardInterface.php');

class AcronisApi_DashboardMock implements AcronisApi_DashboardInterface
{

    private $_enabled = true;
    const SIZE_1GB_BYTES = 1073741824;

    /**
     * Set if backup is enabled or not.
     *
     * @param boolean $isEnabled
     */
    public function setEnabled($isEnabled)
    {
        $this->_enabled = $isEnabled;
    }

    /**
     * Request backup plan.
     *
     * @param string $planId
     * @return array
     */
    public function getBackupPlan($planId = null)
    {
        return array();
    }



    /**
     * Get backup status from Acronis api.
     *
     * @param string $resourceId
     * @return array
     */
    public function getBackupStatus($resourceId)
    {
        return array();
    }

    /**
     * Get backup data from acronis api.
     *
     * @param string $resourceId
     * @return string
     */
    public function getStorageSize($resourceId)
    {
        return self::SIZE_1GB_BYTES;
    }

    /**
     * Request device/server specific backup info.
     *
     * @return array
     */
    public function getDeviceInfo()
    {
        return array();
    }

    /**
     * get agent data.
     *
     * @return array
     */
    public function getAgentData()
    {
        return array();
    }

    /**
     * Gets redirect url that logs in user.
     *
     * @return string
     */
    public function getLoginUrl()
    {
        return 'redirecturl';
    }

    /**
     * get resource id.
     *
     * @return string
     */
    public function getResourceId()
    {
        return 'someresourceid';
    }

    /**
     * get applicable plans.
     *
     * @param string $resourceId
     */
    public function getApplicablePlans($resourceId)
    {

        $plans = $this->_mockPlans();

        return $plans;
    }

    /**
     * get mock plans.
     *
     * @return array
     */
    private function _mockPlans()
    {
        return array();
    }

    /**
     * Create draft for backup plan.
     *
     * @param string $resourceId
     * @return array
     */
    public function createDraft($resourceId)
    {
        return array();
    }

    /**
     *
     * @param string $draftId
     */
    public function editPrePostCommandsDraft($draftId)
    {
    }

    /**
     * Rename backup plan. Does not seem to be another way to name the plan.
     *
     * @param string $draftId
     */
    public function renameDraft($draftId)
    {
        // ...
    }

    /**
     * Create backup plan.
     *
     * @param string $draftId
     */
    public function createPlan($draftId)
    {
        // ...
    }

    /**
     * Assign existing plan to resource.
     *
     * @param string $planId
     * @param string $resourceId
     * @return array
     */
    public function assignPlan($planId, $resourceId)
    {
        // ...
        return array();
    }


    /**
     * Revoke backup plan.
     *
     * @param string $planId
     * @param string $resourceId
     * @return array
     */
    public function revokePlan($planId, $resourceId)
    {
        return array();
    }

    /**
     * Run backup.
     *
     * @param string $planId
     * @param string $resourceId
     * @return array
     */
    public function runBackup($planId, $resourceId)
    {
        return array();
    }

    /**
     *
     * @param array  $plan
     * @param string $resourceId
     * @return boolean
     */
    public function planTargetsResource(array $plan, $resourceId)
    {
        return true;
    }
}
