const imgPath = '/plugins/assets/acronis/images/ajax-loader.gif';
const spinnerClass = 'ab-spinner';
const dashboardCtrl = '/nodeworx/acronis';
const sessionStorageKeyMessages = 'messages';
const xhrInput = {
    iw_payload_output: 'json',
    security_token: iw_js_data.iw_env.security_token
};

export const refreshPage = () => location.reload();
export const getDataFromReply = (reply) => reply.getReplyData().data;


export const sendDashboardRequest = (actionToCall, callback) => {
    iw_ctrl_handler.execute(null, callback, dashboardCtrl, actionToCall, xhrInput)
};

export const createSpinner = () => {
    let $wrapper = $(`<div class="${spinnerClass}"></div>`);
    let $img = $(`<img src="${imgPath}" alt="loading">`);

    $wrapper.append($img);
    return $wrapper;
}

export const loadSectionContent = (section) => {
    let action = section.action;
    let callback = section.callback;

    sendDashboardRequest(action, callback);
}

export const loadMessages = () => {
    let message = getMessage();

    if (message && message.type === 'error') {
        displayErrorMessage(message.message);
    }

    if (message && message.type === 'success') {
         displaySuccessMessage(message.message)
    }

    if (message !== null) {
        // clear message once it has been displayed.
        sessionStorage.removeItem(sessionStorageKeyMessages);
    }
}

const displayErrorMessage = (message) => iw_lib.iw_message_banner(message, 'iw-negative');
const displaySuccessMessage = (message) => iw_lib.iw_message_banner(message, 'iw-positive');

export const setMessageAndRefreshPage = (type, message) => {
    setMessage(type, message);
    refreshPage();
}

export const setMessage = (type, message) => {
    let storageMessage = JSON.stringify({
        type: type,
        message: message
    });

    sessionStorage.setItem(sessionStorageKeyMessages, storageMessage);
}

export const getMessage = () => {
    let message = sessionStorage.getItem(sessionStorageKeyMessages);
    return JSON.parse(message);
}

export const clearMessages = () => sessionStorage.removeItem(sessionStorageKeyMessages);

export const responseError = (reply) => {
    let data = reply.getReplyData();
    let responseError = typeof data.error !== 'undefined';
    return responseError;
}

export const handleResponseError = (reply) => {
    let data = reply.getReplyData();
    displayErrorMessage(data.message);
}
