#!/bin/bash
mysqldir=$TMP_BACKUP_DIR/pre-acronis-mysql
[ ! -d $mysqldir/ ] && mkdir -p $mysqldir/
[ ! -d $mysqldir/log/ ] && mkdir $mysqldir/log/
log="$mysqldir/log/dump.log"
ec() { #color printing removed, may add back if I figure out the bugs.
        shift
        echo -e "${*}" | logit
}
logit() { #print passed stdin, add a timestamp and also echo to the logfile
        while read line; do
                echo "$line"
                echo "$(date -u +"%F %H:%M:%S %Z") $line" >> $log
        done
}
#Do not dump dbs if there may not be space. Set for 50% of datadir usage currently.
percofmysqlusage=50
mysql_datadir=$(mysql -BNe 'show variables like "datadir"' | awk '{print $2}')
mysqldirsize=$(du -s $mysql_datadir | awk '{print $1}')
mysqlestusage=$(echo $(( mysqldirsize*50/100 )))
tmpdiravail=$(df /home | awk '{print $4}' | sed '1 d')
if [[ $mysqlestusage -gt $tmpdiravail ]] ; then
        echo Estimated db dumps to large for available space. $mysqlestusage greater than $tmpdiravail
        echo Adjust percofmysqlusage= in plugins/acronis/scripts/AgentCommData/create-mysql-dumps.sh if needed.
        exit
fi
#We may need to think about how we are going to handle remote db servers.  For now I think we exclude and look at adding an option later to include.  A dedicated mysql server should really have its own backups.
#Set mysqldump options.
mysqldumpopts="--opt --routines --force --log-error=$remote_tempdir/dbdump.log --max_allowed_packet=1000000000"
#Not really needed but might as well grab the grants.
mysql -B -N -e "SELECT DISTINCT CONCAT('SHOW GRANTS FOR ''', user, '''@''', host, ''';') AS query FROM mysql.user" | while read i; do mysql -e "$i"; done | sed 's/\(GRANT .*\)/\1;/;s/^\(Grants for .*\)/## \1 ##/;/##/{x;p;x;}' | sed 's/\\\\/\\/g' > $mysqldir/mysql.grants.local.sql
#user db tb dumps.
mysql_dbdump() { #accepts user as $1, domain as $2
        [ ! -d $mysqldir/$user-dumps/ ] && mkdir $mysqldir/$user-dumps/
        local user=$1
        local dbs=$(siteworx -u --login_domain $domain  -c MysqlDb -a listMysqlDatabases -n | awk '{print $2}')
        for db in $dbs; do
                # routines first
                mysqldump -ntdR ${db} 2>> $mysqldir/log/dbdump.log | > $mysqldir/$user-dumps/${db}-routines.sql 2>> $mysqldir/log/dbdump.log
                # enumerate tables
                local tables=$(mysql ${db} -Bse 'show tables')
                local table_count=$(echo "$tables" | wc -l)
                local n=1
                # dump tables
                [ "$tables" ] && for tb in $(echo $tables); do
                        local tableprog="$n/$table_count"
                                ec purple "$progress dump of ${db}.${tb} ($tableprog)..."
                                mysqldump $mysqldumpopts ${db} ${tb} 2>> $mysqldir/log/dbdump.log | gzip -9 > $mysqldir/$user-dumps/${db}.${tb}.sql.gz 2>> $mysqldir/log/dbdump.log
                        let n+=1
                done
        done
        ec green "$progress All databases for $user complete!"
}
#Get master domains and users for mysql dumps.
#nodeworx -u -c Siteworx -a listAccounts -n | awk '{print $2, $9}' | while read user domain
#
nodeworx -u -c Siteworx -a listMasterDomains | while read d ; do echo $d $(nodeworx -u -c Siteworx -a listAccounts -n | grep $d | awk '{print $2}') ; done | while read domain user
do
mysql_dbdump $user $domain >> $mysqldir/log/dblog.$user.log